package java.text;

import sun.text.IntHashtable;
import java.util.Vector;
import sun.text.UCompactIntArray;

final class RBCollationTables
{
    static final int EXPANDCHARINDEX = 2113929216;
    static final int CONTRACTCHARINDEX = 2130706432;
    static final int UNMAPPED = -1;
    static final int PRIMARYORDERMASK = -65536;
    static final int SECONDARYORDERMASK = 65280;
    static final int TERTIARYORDERMASK = 255;
    static final int PRIMARYDIFFERENCEONLY = -65536;
    static final int SECONDARYDIFFERENCEONLY = -256;
    static final int PRIMARYORDERSHIFT = 16;
    static final int SECONDARYORDERSHIFT = 8;
    private String rules;
    private boolean frenchSec;
    private boolean seAsianSwapping;
    private UCompactIntArray mapping;
    private Vector<Vector<EntryPair>> contractTable;
    private Vector<int[]> expandTable;
    private IntHashtable contractFlags;
    private short maxSecOrder;
    private short maxTerOrder;
    
    public RBCollationTables(String rules, int n) throws ParseException {
        this.rules = null;
        this.frenchSec = false;
        this.seAsianSwapping = false;
        this.mapping = null;
        this.contractTable = null;
        this.expandTable = null;
        this.contractFlags = null;
        this.maxSecOrder = 0;
        this.maxTerOrder = 0;
        this.rules = rules;
        new RBTableBuilder(new RBCollationTables.BuildAPI()).build(rules, n);
    }
    
    public String getRules() {
        return this.rules;
    }
    
    public boolean isFrenchSec() {
        return this.frenchSec;
    }
    
    public boolean isSEAsianSwapping() {
        return this.seAsianSwapping;
    }
    
    Vector<EntryPair> getContractValues(int index) {
        return this.getContractValuesImpl(this.mapping.elementAt(index) - 2130706432);
    }
    
    private Vector<EntryPair> getContractValuesImpl(int index) {
        if (index >= 0) {
            return (Vector)this.contractTable.elementAt(index);
        }
        return null;
    }
    
    boolean usedInContractSeq(int key) {
        return this.contractFlags.get(key) == 1;
    }
    
    int getMaxExpansion(int n) {
        int n2 = 1;
        if (this.expandTable != null) {
            for (int i = 0; i < this.expandTable.size(); ++i) {
                int[] array = (int[])this.expandTable.elementAt(i);
                int length = array.length;
                if (length > n2 && array[length - 1] == n) {
                    n2 = length;
                }
            }
        }
        return n2;
    }
    
    final int[] getExpandValueList(int n) {
        return (int[])this.expandTable.elementAt(n - 2113929216);
    }
    
    int getUnicodeOrder(int index) {
        return this.mapping.elementAt(index);
    }
    
    short getMaxSecOrder() {
        return this.maxSecOrder;
    }
    
    short getMaxTerOrder() {
        return this.maxTerOrder;
    }
    
    static void reverse(StringBuffer sb, int i, int n) {
        for (int n2 = n - 1; i < n2; ++i, --n2) {
            int char1 = sb.charAt(i);
            sb.setCharAt(i, sb.charAt(n2));
            sb.setCharAt(n2, (char)char1);
        }
    }
    
    static final int getEntry(Vector<EntryPair> vector, String anObject, boolean b) {
        int i = 0;
        while (i < vector.size()) {
            EntryPair entryPair = (EntryPair)vector.elementAt(i);
            if (entryPair.fwd == b && entryPair.entryName.equals(anObject)) {
                return i;
            }
            ++i;
        }
        return -1;
    }
    
    final class BuildAPI
    {
        private BuildAPI() {
        }
        
        void fillInTables(boolean b, boolean b2, UCompactIntArray uCompactIntArray, Vector<Vector<EntryPair>> vector, Vector<int[]> vector2, IntHashtable intHashtable, short n, short n2) {
            RBCollationTables.this.frenchSec = b;
            RBCollationTables.this.seAsianSwapping = b2;
            RBCollationTables.this.mapping = uCompactIntArray;
            RBCollationTables.this.contractTable = vector;
            RBCollationTables.this.expandTable = vector2;
            RBCollationTables.this.contractFlags = intHashtable;
            RBCollationTables.this.maxSecOrder = n;
            RBCollationTables.this.maxTerOrder = n2;
        }
    }
}
